==> session-checker-0.2.0-20140326.152640-14-servicearchive.tar.gz: org/gcube/portlets/widgets/sessionchecker/server/SessionCheckerServiceImpl.java <==
package org.gcube.portlets.widgets.sessionchecker.server;

import java.util.Date;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.application.framework.core.session.SessionManager;
import org.gcube.portal.custom.scopemanager.scopehelper.ScopeHelper;
import org.gcube.portlets.widgets.sessionchecker.client.SessionCheckerService;
import org.gcube.portlets.widgets.sessionchecker.shared.SessionInfoBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

/**
 * The server side implementation of the RPC service.
 */
@SuppressWarnings("serial")
public class SessionCheckerServiceImpl extends RemoteServiceServlet implements  SessionCheckerService {

	private static final Logger _log = LoggerFactory.getLogger(SessionCheckerServiceImpl.class);

	private static final String FIRST_TIME = "FIRST_TIME_DEV_MODE";

	/**
	 * the current ASLSession
	 * @return .
	 */
	private ASLSession getASLSession() {	
		try {
			String sessionID = this.getThreadLocalRequest().getSession().getId();
			String user = (String) this.getThreadLocalRequest().getSession().getAttribute(ScopeHelper.USERNAME_ATTRIBUTE);
			System.out.println("\n\n***SessionCheckerServiceImpl USER = " + user + " ID = " + sessionID);
			SessionManager manager = SessionManager.getInstance();
			System.out.println("session manager null?" + manager == null);
			ASLSession toReturn = manager.getASLSession(sessionID, user);
			return toReturn;
		}
		catch (NullPointerException e) {
			_log.warn("Session is null, perhaps you refreshed your application");
			e.printStackTrace();
			return null;
		}
	}

	@Override
	public SessionInfoBean checkSession() {
		if (isFirstTime() == null) 
			setFirstTimeCheck(true);

		ASLSession session = getASLSession();
		getASLSession().invalidate();
		if (session == null)
			return new SessionInfoBean("","", true); //you are in development mode and refreshed the browser	

		String user = session.getUsername();
		String scope = session.getScope();

		//check devMode
		if (user == null && isFirstTime()) {
			_log.warn("Stopping session polling as you are in dev mode (I think, am I wrong?)");		
			return new SessionInfoBean("","", true); //tells that you are in development mode (you must be unless you're session expires in less than a minute)	
		}		
		//else
		setFirstTimeCheck(false);
		_log.trace("Session check OK for " + user + " at " + new Date());
		if (user == null || user.compareTo("") == 0) {
			_log.warn("User is null at " + new Date());			
		}
		if (scope == null || scope.compareTo("") == 0) {
			_log.warn("Scope is null at " + new Date());
		}
		return new SessionInfoBean(session.getUsername(), session.getScope());
	}

	private void setFirstTimeCheck(boolean isFirstTime) {
		_log.trace("setFirstTimeCheck " + isFirstTime);
		getASLSession().setAttribute(FIRST_TIME, isFirstTime);
		getASLSession().increaseSessionTimeout(120000, false);
		_log.trace("asl timeout increased by 2 minutes ");
	}

	private Boolean isFirstTime() {
		Boolean toReturn =  (Boolean) getASLSession().getAttribute(FIRST_TIME);
		_log.trace("isFirstTime() " + toReturn);
		return toReturn;
	}
}

==> session-checker-0.2.0-20140326.154403-15-servicearchive.tar.gz: org/gcube/portlets/widgets/sessionchecker/server/SessionCheckerServiceImpl.java <==
package org.gcube.portlets.widgets.sessionchecker.server;

import java.util.Date;

import org.gcube.application.framework.core.session.ASLSession;
import org.gcube.application.framework.core.session.SessionManager;
import org.gcube.portal.custom.scopemanager.scopehelper.ScopeHelper;
import org.gcube.portlets.widgets.sessionchecker.client.SessionCheckerService;
import org.gcube.portlets.widgets.sessionchecker.shared.SessionInfoBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

/**
 * The server side implementation of the RPC service.
 */
@SuppressWarnings("serial")
public class SessionCheckerServiceImpl extends RemoteServiceServlet implements  SessionCheckerService {

	private static final Logger _log = LoggerFactory.getLogger(SessionCheckerServiceImpl.class);

	private static final String FIRST_TIME = "FIRST_TIME_DEV_MODE";

	/**
	 * the current ASLSession
	 * @return .
	 */
	private ASLSession getASLSession() {	
		try {
			String sessionID = this.getThreadLocalRequest().getSession().getId();
			String user = (String) this.getThreadLocalRequest().getSession().getAttribute(ScopeHelper.USERNAME_ATTRIBUTE);
			System.out.println("***SessionCheckerServiceImpl USER = " + user + " ID = " + sessionID);
			SessionManager manager = SessionManager.getInstance();
			ASLSession toReturn = manager.getASLSession(sessionID, user);
			return toReturn;
		}
		catch (NullPointerException e) {
			_log.warn("Session is null, perhaps you refreshed your application");
			return null;
		}
	}

	@Override
	public SessionInfoBean checkSession() {
		if (isFirstTime() == null) 
			setFirstTimeCheck(true);

		ASLSession session = getASLSession();
		if (session == null)
			return new SessionInfoBean("","", true); //you are in development mode and refreshed the browser	

		String user = session.getUsername();
		String scope = session.getScope();

		//check devMode
		if (user == null && isFirstTime()) {
			_log.warn("Stopping session polling as you are in dev mode (I think, am I wrong?)");		
			return new SessionInfoBean("","", true); //tells that you are in development mode (you must be unless you're session expires in less than a minute)	
		}		
		//else
		setFirstTimeCheck(false);
		_log.trace("Session check OK for " + user + " at " + new Date());
		if (user == null || user.compareTo("") == 0) {
			_log.warn("User is null at " + new Date());			
		}
		if (scope == null || scope.compareTo("") == 0) {
			_log.warn("Scope is null at " + new Date());
		}
		return new SessionInfoBean(session.getUsername(), session.getScope());
	}

	private void setFirstTimeCheck(boolean isFirstTime) {

		ASLSession session = getASLSession();
		_log.trace("setFirstTimeCheck " + isFirstTime);
		session.setAttribute(FIRST_TIME, isFirstTime);
		session.increaseSessionTimeout(120000, false);
		_log.trace("asl timeout increased by 2 minutes ");
	}

	private Boolean isFirstTime() {
		Boolean toReturn =  (Boolean) getASLSession().getAttribute(FIRST_TIME);
		_log.trace("isFirstTime() " + toReturn);
		return toReturn;
	}
}
